@@ -1,5 +1,5 @@
 package Text::NeatTemplate;
-$Text::NeatTemplate::VERSION = '0.1101';
+$Text::NeatTemplate::VERSION = '0.1200';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ Text::NeatTemplate - a fast, middleweight template engine.
 
 =head1 VERSION
 
-version 0.1101
+version 0.1200
 
 =head1 SYNOPSIS
 
@@ -172,6 +172,12 @@ Convert to a string containing alphanumeric characters, dashes
 and underscores; spaces are converted to underscores.
 (useful for anchors or filenames)
 
+=item alphahash
+
+Convert to a string containing only alphanumeric characters
+and then prefix with a hash (#) character
+(useful for anchors or tags)
+
 =item comma_front
 
 Put anything after the last comma at the front (as with an author name)
@@ -713,6 +719,11 @@ sub convert_value {
 	    $value =~ s/ /_/g;
 	    return $value;
 	};
+	/^alphahash/i && do {
+	    $value =~ s/[^a-zA-Z0-9]//g;
+            $value = "#${value}";
+	    return $value;
+	};
 	/^alpha/i && do {
 	    $value =~ s/[^a-zA-Z0-9]//g;
 	    return $value;
